@@ -38,25 +38,25 @@ async function handler(assetHashes) {
   }
   let deleted = 0;
   let reclaimed = 0;
-  let nextToken;
+  let nextKeyMarker;
   let finished = false;
   while (!finished) {
-    const response = await s3.listObjectsV2({
+    const response = await s3.listObjectVersions({
       Bucket: process.env.BUCKET_NAME,
-      ContinuationToken: nextToken
+      KeyMarker: nextKeyMarker
     }).promise();
-    const toDelete = (_a = response.Contents) == null ? void 0 : _a.filter((x) => {
-      if (!x.Key) {
+    const toDelete = (_a = response.Versions) == null ? void 0 : _a.filter((v) => {
+      if (!v.Key) {
         return false;
       }
-      const hash = path.basename(x.Key, path.extname(x.Key));
+      const hash = path.basename(v.Key, path.extname(v.Key));
       let pred = !assetHashes.includes(hash);
       if (process.env.RETAIN_MILLISECONDS) {
-        if (!x.LastModified) {
+        if (!v.LastModified) {
           return false;
         }
         const limitDate = new Date(Date.now() - parseInt(process.env.RETAIN_MILLISECONDS));
-        pred = pred && x.LastModified < limitDate;
+        pred = pred && v.LastModified < limitDate;
       }
       return pred;
     });
@@ -65,15 +65,15 @@ async function handler(assetHashes) {
         await s3.deleteObjects({
           Bucket: process.env.BUCKET_NAME,
           Delete: {
-            Objects: toDelete.map((x) => ({ Key: x.Key }))
+            Objects: toDelete.map((v) => ({ Key: v.Key, VersionId: v.VersionId }))
           }
         }).promise();
       }
       deleted += toDelete.length;
       reclaimed += toDelete.reduce((acc, x) => acc + (x.Size ?? 0), 0);
     }
-    nextToken = response.NextContinuationToken;
-    if (nextToken === void 0) {
+    nextKeyMarker = response.NextKeyMarker;
+    if (nextKeyMarker === void 0) {
       finished = true;
     }
   }
